package com.link.core.webservice;

import com.link.core.util.UserUtil;
import java.util.Set;
import javax.xml.namespace.QName;
import javax.xml.soap.SOAPEnvelope;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPHeader;
import javax.xml.soap.SOAPHeaderElement;
import javax.xml.soap.SOAPMessage;
import javax.xml.ws.handler.MessageContext;
import javax.xml.ws.handler.soap.SOAPHandler;
import javax.xml.ws.handler.soap.SOAPMessageContext;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class LinkHeaderHandler implements SOAPHandler<SOAPMessageContext> {
   private static final Logger logger = LogManager.getLogger(LinkHeaderHandler.class);
   private static String sessionToken;
   private static Long lastTime;
   private final Long maxTime = 600000L;
   private final String sessionType = "Stateless";

   public static String getSessionToken() {
      return sessionToken;
   }

   public static void setSessionToken(String sessionToken) {
      LinkHeaderHandler.sessionToken = sessionToken;
   }

   public static Long getLastTime() {
      return lastTime;
   }

   public static void setLastTime(Long lastTime) {
      LinkHeaderHandler.lastTime = lastTime;
   }

   public boolean handleMessage(SOAPMessageContext context) {
      Boolean isRequest = (Boolean)context.get("javax.xml.ws.handler.message.outbound");
      QName usernameQName = new QName("http://siebel.com/webservices", "UsernameToken", "linkwsh");
      QName passwordQName = new QName("http://siebel.com/webservices", "PasswordText", "linkwsh");
      QName sessionTypeQName = new QName("http://siebel.com/webservices", "SessionType", "linkwsh");
      new QName("http://siebel.com/webservices", "SessionToken", "linkwsh");
      if (isRequest) {
         try {
            SOAPMessage soapMsg = context.getMessage();
            SOAPEnvelope soapEnv = soapMsg.getSOAPPart().getEnvelope();
            SOAPHeader soapHeader = soapEnv.getHeader();
            soapEnv.addNamespaceDeclaration("linkwsh", "http://siebel.com/webservices");
            if (soapHeader == null) {
               soapHeader = soapEnv.addHeader();
            }

            SOAPHeaderElement usernameHeaderElement = soapHeader.addHeaderElement(usernameQName);
            String userName = UserUtil.getUser().getUsername();
            usernameHeaderElement.addTextNode(userName);
            SOAPHeaderElement passwordHeaderElement = soapHeader.addHeaderElement(passwordQName);
            String password = UserUtil.getUser().getPassword();
            passwordHeaderElement.addTextNode(password);
            SOAPHeaderElement SessionTypeHeaderElement = soapHeader.addHeaderElement(sessionTypeQName);
            SessionTypeHeaderElement.addTextNode("Stateless");
            soapMsg.saveChanges();
         } catch (SOAPException var15) {
            SOAPException e = var15;
            logger.warn(e.getMessage());
         } catch (Exception var16) {
            Exception e = var16;
            logger.error(e.getMessage(), e);
         }
      }

      return true;
   }

   public boolean handleFault(SOAPMessageContext context) {
      logger.warn("webservice 错误");
      return true;
   }

   public void close(MessageContext context) {
   }

   public Set<QName> getHeaders() {
      return null;
   }
}
